# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/address_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1 import address_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/vpc/v1/address_service.proto\x12\x13yandex.cloud.vpc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a!yandex/cloud/vpc/v1/address.proto\"5\n\x11GetAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"F\n\x18GetAddressByValueRequest\x12\x1f\n\x15\x65xternal_ipv4_address\x18\x01 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ress\"\x85\x01\n\x14ListAddressesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"a\n\x15ListAddressesResponse\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.vpc.v1.Address\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x04\n\x14\x43reateAddressRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x04name\x18\x02 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.CreateAddressRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12R\n\x1a\x65xternal_ipv4_address_spec\x18\x05 \x01(\x0b\x32,.yandex.cloud.vpc.v1.ExternalIpv4AddressSpecH\x00\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12<\n\x10\x64ns_record_specs\x18\x0b \x03(\x0b\x32\".yandex.cloud.vpc.v1.DnsRecordSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0c\x61\x64\x64ress_specJ\x04\x08\x06\x10\n\"{\n\x17\x45xternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07zone_id\x18\x02 \x01(\t\x12>\n\x0crequirements\x18\x03 \x01(\x0b\x32(.yandex.cloud.vpc.v1.AddressRequirements\"k\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x0b\x64ns_zone_id\x18\x02 \x01(\tB\n\xe8\xc7\x31\x01\x8a\xc8\x31\x02\x32\x30\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"+\n\x15\x43reateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"\xe8\x03\n\x14UpdateAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04name\x18\x03 \x01(\tB.\xf2\xc7\x31*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x82\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.vpc.v1.UpdateAddressRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x10\n\x08reserved\x18\x06 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12<\n\x10\x64ns_record_specs\x18\x08 \x03(\x0b\x32\".yandex.cloud.vpc.v1.DnsRecordSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t\"~\n\x1cListAddressOperationsRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"o\n\x1dListAddressOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x12MoveAddressRequest\x12 \n\naddress_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13MoveAddressMetadata\x12\x12\n\naddress_id\x18\x01 \x01(\t2\xc7\t\n\x0e\x41\x64\x64ressService\x12s\n\x03Get\x12&.yandex.cloud.vpc.v1.GetAddressRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"&\x82\xd3\xe4\x93\x02 \x12\x1e/vpc/v1/addresses/{address_id}\x12|\n\nGetByValue\x12-.yandex.cloud.vpc.v1.GetAddressByValueRequest\x1a\x1c.yandex.cloud.vpc.v1.Address\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/vpc/v1/addresses:byValue\x12x\n\x04List\x12).yandex.cloud.vpc.v1.ListAddressesRequest\x1a*.yandex.cloud.vpc.v1.ListAddressesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/vpc/v1/addresses\x12\x98\x01\n\x06\x43reate\x12).yandex.cloud.vpc.v1.CreateAddressRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2* \n\x15\x43reateAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02\x16\"\x11/vpc/v1/addresses:\x01*\x12\xa5\x01\n\x06Update\x12).yandex.cloud.vpc.v1.UpdateAddressRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2* \n\x15UpdateAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02#2\x1e/vpc/v1/addresses/{address_id}:\x01*\x12\xb0\x01\n\x06\x44\x65lete\x12).yandex.cloud.vpc.v1.DeleteAddressRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*.\n\x15\x44\x65leteAddressMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02 *\x1e/vpc/v1/addresses/{address_id}\x12\xaa\x01\n\x0eListOperations\x12\x31.yandex.cloud.vpc.v1.ListAddressOperationsRequest\x1a\x32.yandex.cloud.vpc.v1.ListAddressOperationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/vpc/v1/addresses/{address_id}/operations\x12\xa4\x01\n\x04Move\x12\'.yandex.cloud.vpc.v1.MoveAddressRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\x1e\n\x13MoveAddressMetadata\x12\x07\x41\x64\x64ress\x82\xd3\xe4\x93\x02(\"#/vpc/v1/addresses/{address_id}:move:\x01*BV\n\x17yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.address_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.vpc.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1;vpc'
  _GETADDRESSREQUEST.fields_by_name['address_id']._options = None
  _GETADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSESREQUEST.fields_by_name['folder_id']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSESREQUEST.fields_by_name['page_size']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTADDRESSESREQUEST.fields_by_name['page_token']._options = None
  _LISTADDRESSESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEADDRESSREQUEST_LABELSENTRY._options = None
  _CREATEADDRESSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEADDRESSREQUEST.fields_by_name['folder_id']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEADDRESSREQUEST.fields_by_name['name']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _CREATEADDRESSREQUEST.fields_by_name['description']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEADDRESSREQUEST.fields_by_name['labels']._options = None
  _CREATEADDRESSREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DNSRECORDSPEC.fields_by_name['fqdn']._options = None
  _DNSRECORDSPEC.fields_by_name['fqdn']._serialized_options = b'\350\3071\001'
  _DNSRECORDSPEC.fields_by_name['dns_zone_id']._options = None
  _DNSRECORDSPEC.fields_by_name['dns_zone_id']._serialized_options = b'\350\3071\001\212\3101\00220'
  _DNSRECORDSPEC.fields_by_name['ttl']._options = None
  _DNSRECORDSPEC.fields_by_name['ttl']._serialized_options = b'\372\3071\0070-86400'
  _UPDATEADDRESSREQUEST_LABELSENTRY._options = None
  _UPDATEADDRESSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEADDRESSREQUEST.fields_by_name['name']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['name']._serialized_options = b'\362\3071*|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?'
  _UPDATEADDRESSREQUEST.fields_by_name['description']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEADDRESSREQUEST.fields_by_name['labels']._options = None
  _UPDATEADDRESSREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _DELETEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['address_id']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTADDRESSOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _MOVEADDRESSREQUEST.fields_by_name['address_id']._options = None
  _MOVEADDRESSREQUEST.fields_by_name['address_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEADDRESSREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEADDRESSREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ADDRESSSERVICE.methods_by_name['Get']._options = None
  _ADDRESSSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/vpc/v1/addresses/{address_id}'
  _ADDRESSSERVICE.methods_by_name['GetByValue']._options = None
  _ADDRESSSERVICE.methods_by_name['GetByValue']._serialized_options = b'\202\323\344\223\002\033\022\031/vpc/v1/addresses:byValue'
  _ADDRESSSERVICE.methods_by_name['List']._options = None
  _ADDRESSSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/vpc/v1/addresses'
  _ADDRESSSERVICE.methods_by_name['Create']._options = None
  _ADDRESSSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateAddressMetadata\022\007Address\202\323\344\223\002\026\"\021/vpc/v1/addresses:\001*'
  _ADDRESSSERVICE.methods_by_name['Update']._options = None
  _ADDRESSSERVICE.methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateAddressMetadata\022\007Address\202\323\344\223\002#2\036/vpc/v1/addresses/{address_id}:\001*'
  _ADDRESSSERVICE.methods_by_name['Delete']._options = None
  _ADDRESSSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteAddressMetadata\022\025google.protobuf.Empty\202\323\344\223\002 *\036/vpc/v1/addresses/{address_id}'
  _ADDRESSSERVICE.methods_by_name['ListOperations']._options = None
  _ADDRESSSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002+\022)/vpc/v1/addresses/{address_id}/operations'
  _ADDRESSSERVICE.methods_by_name['Move']._options = None
  _ADDRESSSERVICE.methods_by_name['Move']._serialized_options = b'\262\322*\036\n\023MoveAddressMetadata\022\007Address\202\323\344\223\002(\"#/vpc/v1/addresses/{address_id}:move:\001*'
  _globals['_GETADDRESSREQUEST']._serialized_start=270
  _globals['_GETADDRESSREQUEST']._serialized_end=323
  _globals['_GETADDRESSBYVALUEREQUEST']._serialized_start=325
  _globals['_GETADDRESSBYVALUEREQUEST']._serialized_end=395
  _globals['_LISTADDRESSESREQUEST']._serialized_start=398
  _globals['_LISTADDRESSESREQUEST']._serialized_end=531
  _globals['_LISTADDRESSESRESPONSE']._serialized_start=533
  _globals['_LISTADDRESSESRESPONSE']._serialized_end=630
  _globals['_CREATEADDRESSREQUEST']._serialized_start=633
  _globals['_CREATEADDRESSREQUEST']._serialized_end=1159
  _globals['_CREATEADDRESSREQUEST_LABELSENTRY']._serialized_start=1092
  _globals['_CREATEADDRESSREQUEST_LABELSENTRY']._serialized_end=1137
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_start=1161
  _globals['_EXTERNALIPV4ADDRESSSPEC']._serialized_end=1284
  _globals['_DNSRECORDSPEC']._serialized_start=1286
  _globals['_DNSRECORDSPEC']._serialized_end=1393
  _globals['_CREATEADDRESSMETADATA']._serialized_start=1395
  _globals['_CREATEADDRESSMETADATA']._serialized_end=1438
  _globals['_UPDATEADDRESSREQUEST']._serialized_start=1441
  _globals['_UPDATEADDRESSREQUEST']._serialized_end=1929
  _globals['_UPDATEADDRESSREQUEST_LABELSENTRY']._serialized_start=1092
  _globals['_UPDATEADDRESSREQUEST_LABELSENTRY']._serialized_end=1137
  _globals['_UPDATEADDRESSMETADATA']._serialized_start=1931
  _globals['_UPDATEADDRESSMETADATA']._serialized_end=1974
  _globals['_DELETEADDRESSREQUEST']._serialized_start=1976
  _globals['_DELETEADDRESSREQUEST']._serialized_end=2032
  _globals['_DELETEADDRESSMETADATA']._serialized_start=2034
  _globals['_DELETEADDRESSMETADATA']._serialized_end=2077
  _globals['_LISTADDRESSOPERATIONSREQUEST']._serialized_start=2079
  _globals['_LISTADDRESSOPERATIONSREQUEST']._serialized_end=2205
  _globals['_LISTADDRESSOPERATIONSRESPONSE']._serialized_start=2207
  _globals['_LISTADDRESSOPERATIONSRESPONSE']._serialized_end=2318
  _globals['_MOVEADDRESSREQUEST']._serialized_start=2320
  _globals['_MOVEADDRESSREQUEST']._serialized_end=2419
  _globals['_MOVEADDRESSMETADATA']._serialized_start=2421
  _globals['_MOVEADDRESSMETADATA']._serialized_end=2462
  _globals['_ADDRESSSERVICE']._serialized_start=2465
  _globals['_ADDRESSSERVICE']._serialized_end=3688
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/saas/v1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.marketplace.licensemanager.v1 import instance_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/marketplace/licensemanager/saas/v1/instance_service.proto\x12/yandex.cloud.marketplace.licensemanager.saas.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x39yandex/cloud/marketplace/licensemanager/v1/instance.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetInstanceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xda\x01\n\x0fInstanceService\x12\xc6\x01\n\x03Get\x12\x43.yandex.cloud.marketplace.licensemanager.saas.v1.GetInstanceRequest\x1a\x34.yandex.cloud.marketplace.licensemanager.v1.Instance\"D\x82\xd3\xe4\x93\x02>\x12</marketplace/license-manager/saas/v1/instances/{instance_id}B\x99\x01\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.saas.v1.instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3yandex.cloud.api.marketplace.licensemanager.saas.v1Zbgithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/saas/v1;licensemanager'
  _GETINSTANCEREQUEST.fields_by_name['instance_id']._options = None
  _GETINSTANCEREQUEST.fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _INSTANCESERVICE.methods_by_name['Get']._options = None
  _INSTANCESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002>\022</marketplace/license-manager/saas/v1/instances/{instance_id}'
  _globals['_GETINSTANCEREQUEST']._serialized_start=243
  _globals['_GETINSTANCEREQUEST']._serialized_end=290
  _globals['_INSTANCESERVICE']._serialized_start=293
  _globals['_INSTANCESERVICE']._serialized_end=511
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.datasphere.v2.jobs.jobs_pb2
import yandex.cloud.datasphere.v2.jobs.project_job_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProjectJobServiceStub:
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CreateProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates job."""

    Clone: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CloneProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Clone job."""

    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ExecuteProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Runs job execution."""

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CancelProjectJobRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Cancels running job."""

    ReadStdLogs: grpc.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsResponse,
    ]
    """Returns stream of job logs."""

    ReadLogs: grpc.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsResponse,
    ]
    """Returns stream of job logs."""

    DownloadJobFiles: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesResponse,
    ]
    """Returns download urls for job files."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobResponse,
    ]
    """Lists jobs."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.GetProjectJobRequest,
        yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job,
    ]
    """Returns job by id."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified job."""

    DeleteData: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobDataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete job data."""

    DeleteAllData: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteAllProjectJobDataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete all jobs data."""

    SetDataTtl: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlResponse,
    ]
    """Update job data ttl."""

class ProjectJobServiceAsyncStub:
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CreateProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates job."""

    Clone: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CloneProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Clone job."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ExecuteProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Runs job execution."""

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CancelProjectJobRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Cancels running job."""

    ReadStdLogs: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsResponse,
    ]
    """Returns stream of job logs."""

    ReadLogs: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsResponse,
    ]
    """Returns stream of job logs."""

    DownloadJobFiles: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesResponse,
    ]
    """Returns download urls for job files."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobResponse,
    ]
    """Lists jobs."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.GetProjectJobRequest,
        yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job,
    ]
    """Returns job by id."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified job."""

    DeleteData: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobDataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete job data."""

    DeleteAllData: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteAllProjectJobDataRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete all jobs data."""

    SetDataTtl: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlRequest,
        yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlResponse,
    ]
    """Update job data ttl."""

class ProjectJobServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Project Jobs. Do not use these methods manually.
    For working with DataSphere Jobs, install DataSphere CLI via `pip install datasphere`.
    """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CreateProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates job."""

    @abc.abstractmethod
    def Clone(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CloneProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Clone job."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ExecuteProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Runs job execution."""

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.CancelProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Cancels running job."""

    @abc.abstractmethod
    def ReadStdLogs(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsResponse], collections.abc.AsyncIterator[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobStdLogsResponse]]:
        """Returns stream of job logs."""

    @abc.abstractmethod
    def ReadLogs(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsResponse], collections.abc.AsyncIterator[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ReadProjectJobLogsResponse]]:
        """Returns stream of job logs."""

    @abc.abstractmethod
    def DownloadJobFiles(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DownloadProjectJobFilesResponse]]:
        """Returns download urls for job files."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.ListProjectJobResponse]]:
        """Lists jobs."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.GetProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job, collections.abc.Awaitable[yandex.cloud.datasphere.v2.jobs.jobs_pb2.Job]]:
        """Returns job by id."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes specified job."""

    @abc.abstractmethod
    def DeleteData(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteProjectJobDataRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete job data."""

    @abc.abstractmethod
    def DeleteAllData(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.DeleteAllProjectJobDataRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete all jobs data."""

    @abc.abstractmethod
    def SetDataTtl(
        self,
        request: yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.jobs.project_job_service_pb2.SetProjectJobDataTtlResponse]]:
        """Update job data ttl."""

def add_ProjectJobServiceServicer_to_server(servicer: ProjectJobServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cic/v1/peering.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/cic/v1/peering.proto\x12\x13yandex.cloud.cic.v1\"\x8b\x01\n\x07Peering\x12\x16\n\x0epeering_subnet\x18\x01 \x01(\t\x12\x0f\n\x07peer_ip\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_ip\x18\x03 \x01(\t\x12\x14\n\x0cpeer_bgp_asn\x18\x04 \x01(\x03\x12\x15\n\rcloud_bgp_asn\x18\x05 \x01(\x03\x12\x18\n\x10peer_bgp_md5_key\x18\x06 \x01(\tBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.peering_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_PEERING']._serialized_start=59
  _globals['_PEERING']._serialized_end=198
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.serverless.eventrouter.v1 import event_service_pb2 as yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_event__service__pb2


class EventServiceStub(object):
    """Service for put events to bus for serverless eventrouter.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Put = channel.unary_unary(
                '/yandex.cloud.serverless.eventrouter.v1.EventService/Put',
                request_serializer=yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_event__service__pb2.PutEventRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class EventServiceServicer(object):
    """Service for put events to bus for serverless eventrouter.
    """

    def Put(self, request, context):
        """Puts event to bus.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Put': grpc.unary_unary_rpc_method_handler(
                    servicer.Put,
                    request_deserializer=yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_event__service__pb2.PutEventRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.serverless.eventrouter.v1.EventService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventService(object):
    """Service for put events to bus for serverless eventrouter.
    """

    @staticmethod
    def Put(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.serverless.eventrouter.v1.EventService/Put',
            yandex_dot_cloud_dot_serverless_dot_eventrouter_dot_v1_dot_event__service__pb2.PutEventRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.datasphere.v1 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2
from yandex.cloud.datasphere.v1 import project_service_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class ProjectServiceStub(object):
    """A set of methods for managing Project resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Create',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Update',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Delete',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.DeleteProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Open = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Open',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.OpenProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Get',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetProjectRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2.Project.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/List',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsResponse.FromString,
                )
        self.GetUnitBalance = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/GetUnitBalance',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceResponse.FromString,
                )
        self.SetUnitBalance = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/SetUnitBalance',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.SetUnitBalanceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Execute = channel.unary_unary(
                '/yandex.cloud.datasphere.v1.ProjectService/Execute',
                request_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ProjectExecutionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class ProjectServiceServicer(object):
    """A set of methods for managing Project resources.
    """

    def Create(self, request, context):
        """Creates a project in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Open(self, request, context):
        """Opens the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists projects for the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUnitBalance(self, request, context):
        """Returns the unit balance of the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUnitBalance(self, request, context):
        """Sets the unit balance of the specified project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Execute(self, request, context):
        """Executes code in the specified cell or notebook.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.CreateProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.UpdateProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.DeleteProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Open': grpc.unary_unary_rpc_method_handler(
                    servicer.Open,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.OpenProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetProjectRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2.Project.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsResponse.SerializeToString,
            ),
            'GetUnitBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnitBalance,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceResponse.SerializeToString,
            ),
            'SetUnitBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUnitBalance,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.SetUnitBalanceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Execute': grpc.unary_unary_rpc_method_handler(
                    servicer.Execute,
                    request_deserializer=yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ProjectExecutionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.datasphere.v1.ProjectService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectService(object):
    """A set of methods for managing Project resources.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Create',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.CreateProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Update',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.UpdateProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Delete',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.DeleteProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Open(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Open',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.OpenProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Get',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetProjectRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2.Project.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/List',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ListProjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUnitBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/GetUnitBalance',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceRequest.SerializeToString,
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.GetUnitBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUnitBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/SetUnitBalance',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.SetUnitBalanceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Execute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.datasphere.v1.ProjectService/Execute',
            yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__service__pb2.ProjectExecutionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GroupMappingItem(google.protobuf.message.Message):
    """Group mapping represents which external (federated) groups should match which internal (cloud) groups"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_GROUP_ID_FIELD_NUMBER: builtins.int
    INTERNAL_GROUP_ID_FIELD_NUMBER: builtins.int
    external_group_id: builtins.str
    """External group id (received from identity provider)"""
    internal_group_id: builtins.str
    """Internal cloud group id"""
    def __init__(
        self,
        *,
        external_group_id: builtins.str = ...,
        internal_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_group_id", b"external_group_id", "internal_group_id", b"internal_group_id"]) -> None: ...

global___GroupMappingItem = GroupMappingItem

@typing.final
class GroupMapping(google.protobuf.message.Message):
    """Group synchronization status for a specific federation
    Absence of this object for a federation means that there is no group synchronization set of for the federation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """Federation id"""
    enabled: builtins.bool
    """Flag to show whether group synchronization should be enabled for this federation."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "federation_id", b"federation_id"]) -> None: ...

global___GroupMapping = GroupMapping



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.functions.v1.function_pb2
import yandex.cloud.serverless.functions.v1.function_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FunctionServiceStub:
    """A set of methods for managing serverless functions."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Function,
    ]
    """Returns the specified function.

    To get the list of all available functions, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsResponse,
    ]
    """Retrieves the list of functions in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a function in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.UpdateFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified function."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified function."""

    GetVersion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Version,
    ]
    """Returns the specified version of a function.

    To get the list of available version, make a [ListVersions] request.
    """

    GetVersionByTag: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionByTagRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Version,
    ]
    """Returns all versions with the specified tag.

    To get the list of all available versions, make a [ListVersions] request.
    """

    ListVersions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsResponse,
    ]
    """Retrieves the list of versions for the specified function, or of all function versions
    in the specified folder.
    """

    DeleteVersion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified version of a function.

    NOTE: old untagged function versions are deleted automatically.
    """

    SetTag: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.SetFunctionTagRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set a tag for the specified version of a function."""

    RemoveTag: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveFunctionTagRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Remove a tag from the specified version of a function."""

    ListTagHistory: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryResponse,
    ]
    """Returns the log of tags assigned to versions of the specified function."""

    CreateVersion: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a version for the specified function."""

    ListRuntimes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesResponse,
    ]
    """Lists available runtime environments for the specified function."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsResponse,
    ]
    """Lists operations for the specified function."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified function."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the function."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified function."""

    ListScalingPolicies: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesResponse,
    ]
    """Lists existing scaling policies for specified function"""

    SetScalingPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.SetScalingPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set scaling policy for specified function and tag"""

    RemoveScalingPolicy: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveScalingPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Remove scaling policy for specified function and tag"""

class FunctionServiceAsyncStub:
    """A set of methods for managing serverless functions."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Function,
    ]
    """Returns the specified function.

    To get the list of all available functions, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsResponse,
    ]
    """Retrieves the list of functions in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a function in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.UpdateFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified function."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified function."""

    GetVersion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Version,
    ]
    """Returns the specified version of a function.

    To get the list of available version, make a [ListVersions] request.
    """

    GetVersionByTag: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionByTagRequest,
        yandex.cloud.serverless.functions.v1.function_pb2.Version,
    ]
    """Returns all versions with the specified tag.

    To get the list of all available versions, make a [ListVersions] request.
    """

    ListVersions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsResponse,
    ]
    """Retrieves the list of versions for the specified function, or of all function versions
    in the specified folder.
    """

    DeleteVersion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified version of a function.

    NOTE: old untagged function versions are deleted automatically.
    """

    SetTag: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.SetFunctionTagRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set a tag for the specified version of a function."""

    RemoveTag: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveFunctionTagRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Remove a tag from the specified version of a function."""

    ListTagHistory: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryResponse,
    ]
    """Returns the log of tags assigned to versions of the specified function."""

    CreateVersion: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionVersionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a version for the specified function."""

    ListRuntimes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesResponse,
    ]
    """Lists available runtime environments for the specified function."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsResponse,
    ]
    """Lists operations for the specified function."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified function."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the function."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified function."""

    ListScalingPolicies: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesRequest,
        yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesResponse,
    ]
    """Lists existing scaling policies for specified function"""

    SetScalingPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.SetScalingPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set scaling policy for specified function and tag"""

    RemoveScalingPolicy: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveScalingPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Remove scaling policy for specified function and tag"""

class FunctionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing serverless functions."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_pb2.Function, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_pb2.Function]]:
        """Returns the specified function.

        To get the list of all available functions, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsResponse]]:
        """Retrieves the list of functions in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a function in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.UpdateFunctionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified function."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified function."""

    @abc.abstractmethod
    def GetVersion(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_pb2.Version, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_pb2.Version]]:
        """Returns the specified version of a function.

        To get the list of available version, make a [ListVersions] request.
        """

    @abc.abstractmethod
    def GetVersionByTag(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.GetFunctionVersionByTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_pb2.Version, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_pb2.Version]]:
        """Returns all versions with the specified tag.

        To get the list of all available versions, make a [ListVersions] request.
        """

    @abc.abstractmethod
    def ListVersions(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionsVersionsResponse]]:
        """Retrieves the list of versions for the specified function, or of all function versions
        in the specified folder.
        """

    @abc.abstractmethod
    def DeleteVersion(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.DeleteFunctionVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified version of a function.

        NOTE: old untagged function versions are deleted automatically.
        """

    @abc.abstractmethod
    def SetTag(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.SetFunctionTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set a tag for the specified version of a function."""

    @abc.abstractmethod
    def RemoveTag(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveFunctionTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Remove a tag from the specified version of a function."""

    @abc.abstractmethod
    def ListTagHistory(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionTagHistoryResponse]]:
        """Returns the log of tags assigned to versions of the specified function."""

    @abc.abstractmethod
    def CreateVersion(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.CreateFunctionVersionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a version for the specified function."""

    @abc.abstractmethod
    def ListRuntimes(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListRuntimesResponse]]:
        """Lists available runtime environments for the specified function."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListFunctionOperationsResponse]]:
        """Lists operations for the specified function."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified function."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the function."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified function."""

    @abc.abstractmethod
    def ListScalingPolicies(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesResponse, collections.abc.Awaitable[yandex.cloud.serverless.functions.v1.function_service_pb2.ListScalingPoliciesResponse]]:
        """Lists existing scaling policies for specified function"""

    @abc.abstractmethod
    def SetScalingPolicy(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.SetScalingPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set scaling policy for specified function and tag"""

    @abc.abstractmethod
    def RemoveScalingPolicy(
        self,
        request: yandex.cloud.serverless.functions.v1.function_service_pb2.RemoveScalingPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Remove scaling policy for specified function and tag"""

def add_FunctionServiceServicer_to_server(servicer: FunctionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/regression/dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.loadtesting.api.v1.regression import widget_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_regression_dot_widget__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/loadtesting/api/v1/regression/dashboard.proto\x12*yandex.cloud.loadtesting.api.v1.regression\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x37yandex/cloud/loadtesting/api/v1/regression/widget.proto\"\xf0\x02\n\tDashboard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x0c\n\x04\x65tag\x18\x08 \x01(\t\x12N\n\x07\x63ontent\x18\t \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.regression.Dashboard.Content\x1aN\n\x07\x43ontent\x12\x43\n\x07widgets\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.loadtesting.api.v1.regression.WidgetB\x8b\x01\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regressionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.yandex.cloud.api.loadtesting.api.v1.regressionZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/regression;regression'
  _globals['_DASHBOARD']._serialized_start=197
  _globals['_DASHBOARD']._serialized_end=565
  _globals['_DASHBOARD_CONTENT']._serialized_start=487
  _globals['_DASHBOARD_CONTENT']._serialized_end=565
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.containerregistry.v1.repository_pb2
import yandex.cloud.containerregistry.v1.repository_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RepositoryServiceStub:
    """A set of methods for managing Repository resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryRequest,
        yandex.cloud.containerregistry.v1.repository_pb2.Repository,
    ]
    """Returns the specified Repository resource.

    To get the list of available Repository resources, make a [List] request.
    """

    GetByName: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryByNameRequest,
        yandex.cloud.containerregistry.v1.repository_pb2.Repository,
    ]
    """Returns the specified Repository resource.

    To get the list of available Repository resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesRequest,
        yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesResponse,
    ]
    """Retrieves the list of Repository resources in the specified registry."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified repository.
    """

    Upsert: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.UpsertRepositoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts a repository in the specified registry."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.DeleteRepositoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified repository."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified repository."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified repository."""

class RepositoryServiceAsyncStub:
    """A set of methods for managing Repository resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryRequest,
        yandex.cloud.containerregistry.v1.repository_pb2.Repository,
    ]
    """Returns the specified Repository resource.

    To get the list of available Repository resources, make a [List] request.
    """

    GetByName: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryByNameRequest,
        yandex.cloud.containerregistry.v1.repository_pb2.Repository,
    ]
    """Returns the specified Repository resource.

    To get the list of available Repository resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesRequest,
        yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesResponse,
    ]
    """Retrieves the list of Repository resources in the specified registry."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the specified repository.
    """

    Upsert: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.UpsertRepositoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts a repository in the specified registry."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.repository_service_pb2.DeleteRepositoryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified repository."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified repository."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified repository."""

class RepositoryServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Repository resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.repository_pb2.Repository, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.repository_pb2.Repository]]:
        """Returns the specified Repository resource.

        To get the list of available Repository resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByName(
        self,
        request: yandex.cloud.containerregistry.v1.repository_service_pb2.GetRepositoryByNameRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.repository_pb2.Repository, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.repository_pb2.Repository]]:
        """Returns the specified Repository resource.

        To get the list of available Repository resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesResponse, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.repository_service_pb2.ListRepositoriesResponse]]:
        """Retrieves the list of Repository resources in the specified registry."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the specified repository.
        """

    @abc.abstractmethod
    def Upsert(
        self,
        request: yandex.cloud.containerregistry.v1.repository_service_pb2.UpsertRepositoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Upserts a repository in the specified registry."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.containerregistry.v1.repository_service_pb2.DeleteRepositoryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified repository."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified repository."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified repository."""

def add_RepositoryServiceServicer_to_server(servicer: RepositoryServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClaimAgentStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClaimAgentStatusRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: ClaimAgentStatusRequest._Status.ValueType  # 0
        READY_FOR_TEST: ClaimAgentStatusRequest._Status.ValueType  # 1
        PREPARING_TEST: ClaimAgentStatusRequest._Status.ValueType  # 2
        TESTING: ClaimAgentStatusRequest._Status.ValueType  # 3
        TANK_FAILED: ClaimAgentStatusRequest._Status.ValueType  # 4
        STOPPED: ClaimAgentStatusRequest._Status.ValueType  # 5
        UPLOADING_ARTIFACTS: ClaimAgentStatusRequest._Status.ValueType  # 6
        ERROR: ClaimAgentStatusRequest._Status.ValueType  # 7

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: ClaimAgentStatusRequest.Status.ValueType  # 0
    READY_FOR_TEST: ClaimAgentStatusRequest.Status.ValueType  # 1
    PREPARING_TEST: ClaimAgentStatusRequest.Status.ValueType  # 2
    TESTING: ClaimAgentStatusRequest.Status.ValueType  # 3
    TANK_FAILED: ClaimAgentStatusRequest.Status.ValueType  # 4
    STOPPED: ClaimAgentStatusRequest.Status.ValueType  # 5
    UPLOADING_ARTIFACTS: ClaimAgentStatusRequest.Status.ValueType  # 6
    ERROR: ClaimAgentStatusRequest.Status.ValueType  # 7

    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_MESSAGE_FIELD_NUMBER: builtins.int
    agent_instance_id: builtins.str
    status: global___ClaimAgentStatusRequest.Status.ValueType
    status_message: builtins.str
    def __init__(
        self,
        *,
        agent_instance_id: builtins.str = ...,
        status: global___ClaimAgentStatusRequest.Status.ValueType = ...,
        status_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "status", b"status", "status_message", b"status_message"]) -> None: ...

global___ClaimAgentStatusRequest = ClaimAgentStatusRequest

@typing.final
class ClaimAgentStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    def __init__(
        self,
        *,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code"]) -> None: ...

global___ClaimAgentStatusResponse = ClaimAgentStatusResponse

@typing.final
class ReportEventLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_INSTANCE_ID_FIELD_NUMBER: builtins.int
    IDEMPOTENCY_KEY_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    agent_instance_id: builtins.str
    idempotency_key: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventLog]: ...
    def __init__(
        self,
        *,
        agent_instance_id: builtins.str = ...,
        idempotency_key: builtins.str = ...,
        events: collections.abc.Iterable[global___EventLog] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_instance_id", b"agent_instance_id", "events", b"events", "idempotency_key", b"idempotency_key"]) -> None: ...

global___ReportEventLogsRequest = ReportEventLogsRequest

@typing.final
class ReportEventLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportEventLogsResponse = ReportEventLogsResponse

@typing.final
class EventLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Severity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SeverityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EventLog._Severity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SEVERITY_UNSPECIFIED: EventLog._Severity.ValueType  # 0
        DEBUG: EventLog._Severity.ValueType  # 1
        INFO: EventLog._Severity.ValueType  # 2
        WARNING: EventLog._Severity.ValueType  # 3
        ERROR: EventLog._Severity.ValueType  # 4
        FATAL: EventLog._Severity.ValueType  # 5

    class Severity(_Severity, metaclass=_SeverityEnumTypeWrapper): ...
    SEVERITY_UNSPECIFIED: EventLog.Severity.ValueType  # 0
    DEBUG: EventLog.Severity.ValueType  # 1
    INFO: EventLog.Severity.ValueType  # 2
    WARNING: EventLog.Severity.ValueType  # 3
    ERROR: EventLog.Severity.ValueType  # 4
    FATAL: EventLog.Severity.ValueType  # 5

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    MESSAGE_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    message: builtins.str
    severity: global___EventLog.Severity.ValueType
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        severity: global___EventLog.Severity.ValueType = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "metadata", b"metadata", "severity", b"severity", "timestamp", b"timestamp"]) -> None: ...

global___EventLog = EventLog



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MysqlConfig5_7(google.protobuf.message.Message):
    """Options and structure of `MysqlConfig5_7` reflects MySQL 5.7 configuration file"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INNODB_BUFFER_POOL_SIZE_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    LONG_QUERY_TIME_FIELD_NUMBER: builtins.int
    @property
    def innodb_buffer_pool_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Size of the InnoDB buffer pool used for caching table and index data.

        For details, see [MySQL documentation for the parameter](https://dev.mysql.com/doc/refman/5.7/en/innodb-parameters.html#sysvar_innodb_buffer_pool_size).
        """

    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum permitted number of simultaneous client connections.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_max_connections).
        """

    @property
    def long_query_time(self) -> google.protobuf.wrappers_pb2.DoubleValue:
        """Time that it takes to process a query before it is considered slow.

        For details, see [MySQL documentation for the variable](https://dev.mysql.com/doc/refman/5.7/en/server-system-variables.html#sysvar_long_query_time).
        """

    def __init__(
        self,
        *,
        innodb_buffer_pool_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        long_query_time: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["innodb_buffer_pool_size", b"innodb_buffer_pool_size", "long_query_time", b"long_query_time", "max_connections", b"max_connections"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["innodb_buffer_pool_size", b"innodb_buffer_pool_size", "long_query_time", b"long_query_time", "max_connections", b"max_connections"]) -> None: ...

global___MysqlConfig5_7 = MysqlConfig5_7

@typing.final
class MysqlConfigSet5_7(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MysqlConfig5_7:
        """Effective settings for a MySQL 5.7 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MysqlConfig5_7:
        """User-defined settings for a MySQL 5.7 cluster."""

    @property
    def default_config(self) -> global___MysqlConfig5_7:
        """Default configuration for a MySQL 5.7 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MysqlConfig5_7 | None = ...,
        user_config: global___MysqlConfig5_7 | None = ...,
        default_config: global___MysqlConfig5_7 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MysqlConfigSet5_7 = MysqlConfigSet5_7



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartcaptcha/v1/captcha.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/smartcaptcha/v1/captcha.proto\x12\x1cyandex.cloud.smartcaptcha.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xa4\x05\n\x07\x43\x61ptcha\x12\n\n\x02id\x18\x15 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x0c \x01(\t\x12\x12\n\nclient_key\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x15\n\rallowed_sites\x18\x08 \x03(\t\x12\x43\n\ncomplexity\x18\t \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12\x12\n\nstyle_json\x18\n \x01(\t\x12\x0f\n\x07suspend\x18\r \x01(\x08\x12\x1f\n\x17turn_off_hostname_check\x18\x0e \x01(\x08\x12I\n\x0epre_check_type\x18\x10 \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\x11 \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\x12\x42\n\x0esecurity_rules\x18\x13 \x03(\x0b\x32*.yandex.cloud.smartcaptcha.v1.SecurityRule\x12\x1b\n\x13\x64\x65letion_protection\x18\x16 \x01(\x08\x12R\n\x11override_variants\x18\x17 \x03(\x0b\x32-.yandex.cloud.smartcaptcha.v1.OverrideVariantB\x08\x82\xc8\x31\x04<=32J\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x0b\x10\x0cJ\x04\x08\x0f\x10\x10J\x04\x08\x12\x10\x13J\x04\x08\x14\x10\x15\"\xc3\x02\n\x0fOverrideVariant\x12\x34\n\x04uuid\x18\x01 \x01(\tB&\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04<=64\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12\x43\n\ncomplexity\x18\x03 \x01(\x0e\x32/.yandex.cloud.smartcaptcha.v1.CaptchaComplexity\x12I\n\x0epre_check_type\x18\x04 \x01(\x0e\x32\x31.yandex.cloud.smartcaptcha.v1.CaptchaPreCheckType\x12J\n\x0e\x63hallenge_type\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.smartcaptcha.v1.CaptchaChallengeType\"&\n\x10\x43\x61ptchaSecretKey\x12\x12\n\nserver_key\x18\x01 \x01(\t\"\xe9\x01\n\x0cSecurityRule\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe8\xc7\x31\x01\xf2\xc7\x31\x1a[a-zA-Z0-9][a-zA-Z0-9-_.]*\x8a\xc8\x31\x04\x31-50\x12\x1e\n\x08priority\x18\x02 \x01(\x03\x42\x0c\xfa\xc7\x31\x08\x31-999999\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=512\x12:\n\tcondition\x18\x04 \x01(\x0b\x32\'.yandex.cloud.smartcaptcha.v1.Condition\x12\x1d\n\x15override_variant_uuid\x18\x06 \x01(\tJ\x04\x08\x05\x10\x06\"\xd6\x0b\n\tCondition\x12\x41\n\x04host\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.smartcaptcha.v1.Condition.HostMatcher\x12?\n\x03uri\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.smartcaptcha.v1.Condition.UriMatcher\x12P\n\x07headers\x18\x03 \x03(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.HeaderMatcherB\x08\x82\xc8\x31\x04<=20\x12\x44\n\tsource_ip\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.smartcaptcha.v1.Condition.IpMatcher\x1a\xfc\x01\n\rStringMatcher\x12 \n\x0b\x65xact_match\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12$\n\x0f\x65xact_not_match\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12!\n\x0cprefix_match\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10prefix_not_match\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12%\n\x10pire_regex_match\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x12)\n\x14pire_regex_not_match\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05\x30-255H\x00\x42\x07\n\x05match\x1a]\n\x0bHostMatcher\x12N\n\x05hosts\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x08\x82\xc8\x31\x04<=20\x1a\xa2\x01\n\nUriMatcher\x12\x43\n\x04path\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcher\x12O\n\x07queries\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.QueryMatcherB\x08\x82\xc8\x31\x04<=20\x1av\n\x0cQueryMatcher\x12\x1a\n\x03key\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12J\n\x05value\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1ax\n\rHeaderMatcher\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-255\x12J\n\x05value\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.smartcaptcha.v1.Condition.StringMatcherB\x04\xe8\xc7\x31\x01\x1a\xcf\x02\n\tIpMatcher\x12P\n\x0fip_ranges_match\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.smartcaptcha.v1.Condition.IpRangesMatcher\x12T\n\x13ip_ranges_not_match\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.smartcaptcha.v1.Condition.IpRangesMatcher\x12J\n\x0cgeo_ip_match\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.GeoIpMatcher\x12N\n\x10geo_ip_not_match\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.smartcaptcha.v1.Condition.GeoIpMatcher\x1a\x31\n\x0fIpRangesMatcher\x12\x1e\n\tip_ranges\x18\x01 \x03(\tB\x0b\x82\xc8\x31\x07<=10000\x1a\x33\n\x0cGeoIpMatcher\x12#\n\tlocations\x18\x01 \x03(\tB\x10\x82\xc8\x31\x03>=1\x8a\xc8\x31\x01\x32\x90\xc8\x31\x01*g\n\x11\x43\x61ptchaComplexity\x12\"\n\x1e\x43\x41PTCHA_COMPLEXITY_UNSPECIFIED\x10\x00\x12\x08\n\x04\x45\x41SY\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HARD\x10\x03\x12\x0e\n\nFORCE_HARD\x10\x04*W\n\x13\x43\x61ptchaPreCheckType\x12&\n\"CAPTCHA_PRE_CHECK_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43HECKBOX\x10\x01\x12\n\n\x06SLIDER\x10\x02*q\n\x14\x43\x61ptchaChallengeType\x12&\n\"CAPTCHA_CHALLENGE_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nIMAGE_TEXT\x10\x01\x12\x0f\n\x0bSILHOUETTES\x10\x02\x12\x10\n\x0cKALEIDOSCOPE\x10\x03\x42q\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptchab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartcaptcha.v1.captcha_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.smartcaptcha.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartcaptcha/v1;smartcaptcha'
  _CAPTCHA.fields_by_name['override_variants']._options = None
  _CAPTCHA.fields_by_name['override_variants']._serialized_options = b'\202\3101\004<=32'
  _OVERRIDEVARIANT.fields_by_name['uuid']._options = None
  _OVERRIDEVARIANT.fields_by_name['uuid']._serialized_options = b'\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\004<=64'
  _OVERRIDEVARIANT.fields_by_name['description']._options = None
  _OVERRIDEVARIANT.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _SECURITYRULE.fields_by_name['name']._options = None
  _SECURITYRULE.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\032[a-zA-Z0-9][a-zA-Z0-9-_.]*\212\3101\0041-50'
  _SECURITYRULE.fields_by_name['priority']._options = None
  _SECURITYRULE.fields_by_name['priority']._serialized_options = b'\372\3071\0101-999999'
  _SECURITYRULE.fields_by_name['description']._options = None
  _SECURITYRULE.fields_by_name['description']._serialized_options = b'\212\3101\005<=512'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['exact_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['prefix_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._options = None
  _CONDITION_STRINGMATCHER.fields_by_name['pire_regex_not_match']._serialized_options = b'\212\3101\0050-255'
  _CONDITION_HOSTMATCHER.fields_by_name['hosts']._options = None
  _CONDITION_HOSTMATCHER.fields_by_name['hosts']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_URIMATCHER.fields_by_name['queries']._options = None
  _CONDITION_URIMATCHER.fields_by_name['queries']._serialized_options = b'\202\3101\004<=20'
  _CONDITION_QUERYMATCHER.fields_by_name['key']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_QUERYMATCHER.fields_by_name['value']._options = None
  _CONDITION_QUERYMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_HEADERMATCHER.fields_by_name['name']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\0051-255'
  _CONDITION_HEADERMATCHER.fields_by_name['value']._options = None
  _CONDITION_HEADERMATCHER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._options = None
  _CONDITION_IPRANGESMATCHER.fields_by_name['ip_ranges']._serialized_options = b'\202\3101\007<=10000'
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._options = None
  _CONDITION_GEOIPMATCHER.fields_by_name['locations']._serialized_options = b'\202\3101\003>=1\212\3101\0012\220\3101\001'
  _CONDITION.fields_by_name['headers']._options = None
  _CONDITION.fields_by_name['headers']._serialized_options = b'\202\3101\004<=20'
  _globals['_CAPTCHACOMPLEXITY']._serialized_start=2918
  _globals['_CAPTCHACOMPLEXITY']._serialized_end=3021
  _globals['_CAPTCHAPRECHECKTYPE']._serialized_start=3023
  _globals['_CAPTCHAPRECHECKTYPE']._serialized_end=3110
  _globals['_CAPTCHACHALLENGETYPE']._serialized_start=3112
  _globals['_CAPTCHACHALLENGETYPE']._serialized_end=3225
  _globals['_CAPTCHA']._serialized_start=141
  _globals['_CAPTCHA']._serialized_end=817
  _globals['_OVERRIDEVARIANT']._serialized_start=820
  _globals['_OVERRIDEVARIANT']._serialized_end=1143
  _globals['_CAPTCHASECRETKEY']._serialized_start=1145
  _globals['_CAPTCHASECRETKEY']._serialized_end=1183
  _globals['_SECURITYRULE']._serialized_start=1186
  _globals['_SECURITYRULE']._serialized_end=1419
  _globals['_CONDITION']._serialized_start=1422
  _globals['_CONDITION']._serialized_end=2916
  _globals['_CONDITION_STRINGMATCHER']._serialized_start=1720
  _globals['_CONDITION_STRINGMATCHER']._serialized_end=1972
  _globals['_CONDITION_HOSTMATCHER']._serialized_start=1974
  _globals['_CONDITION_HOSTMATCHER']._serialized_end=2067
  _globals['_CONDITION_URIMATCHER']._serialized_start=2070
  _globals['_CONDITION_URIMATCHER']._serialized_end=2232
  _globals['_CONDITION_QUERYMATCHER']._serialized_start=2234
  _globals['_CONDITION_QUERYMATCHER']._serialized_end=2352
  _globals['_CONDITION_HEADERMATCHER']._serialized_start=2354
  _globals['_CONDITION_HEADERMATCHER']._serialized_end=2474
  _globals['_CONDITION_IPMATCHER']._serialized_start=2477
  _globals['_CONDITION_IPMATCHER']._serialized_end=2812
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_start=2814
  _globals['_CONDITION_IPRANGESMATCHER']._serialized_end=2863
  _globals['_CONDITION_GEOIPMATCHER']._serialized_start=2865
  _globals['_CONDITION_GEOIPMATCHER']._serialized_end=2916
# @@protoc_insertion_point(module_scope)
